package cz.cca.training.dao;

import cz.cca.training.entity.ActionEO;
import cz.cca.training.utils.ResolveException;
import java.util.List;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

/**
 * <p>
 * Title: {@link ActionDAOBean}
 * </p>
 * <p>
 * Description: DAO for basic work with action.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 3. 2015 16:21:41
 */
@Stateless
public class ActionDAOBean implements ActionDAO {

    @PersistenceContext
    private EntityManager entityManager;

    @Override
    public void saveAction(final ActionEO entity) {
        try {
            entityManager.persist(entity);
        }
        catch (RuntimeException re) {
            ResolveException.printException(re, "Connection to database failed!");
        }
    }

    @Override
    public void deleteAction(final ActionEO entity) {
        entityManager.remove(
            entityManager.getReference(
                            ActionEO.class,
                            entity.getIdAction()));
    }

    @Override
    public ActionEO updateAction(final ActionEO entity) {
            return entityManager.merge(entity);
    }

    @Override
    public ActionEO getAction(final int id) {
            return entityManager.find(ActionEO.class, id);
    }

    @Override
    public List<ActionEO> getAllAction() {
        return entityManager
            .createNamedQuery(
                ActionEO.ALL,
                ActionEO.class)
                    .getResultList();
    }
}
