package cz.cca.training.dao;

import cz.cca.training.entity.CenterEO;
import cz.cca.training.entity.EmployeeEO;
import cz.cca.training.entity.TypeRelationshipEO;
import java.util.List;

/**
 * <p>
 * Title: {@link EmployeeDAO}
 * </p>
 * <p>
 * Description: Interface with necessary methods for basic work about employee.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 26. 3. 2015 11:45:13
 */
public interface EmployeeDAO {
   
    /**
     * @param entity employee entity
     */
    void saveEmployee(final EmployeeEO entity);

    /**
     * @param entity employee entity
     */
    void deleteEmployee(final EmployeeEO entity);

     /**
     * @param entity employee entity
     * @return result about updated entity 
     */
    EmployeeEO updateEmployee(final EmployeeEO entity);

    /**
     * Get detail employee according the identifier
     * 
     * @param id the identifier employee
     * @return required employee
     */
    EmployeeEO getEmployee(final int id);

    /**
     * Get all employees.
     *
     * @return list of all employee entities
     */
    List<EmployeeEO> getAllEmployees();

    /**
     * Get all employees for browse grid.
     *
     * @return list of all employee entities
     */
    List<EmployeeEO> getAllEmployeesForBrowse();

    /**
     * Get all centers for combo box
     *
     * @return list of all centers entities
     */
    List<CenterEO> getAllCenter();
    
    /**
     * Get center according id
     *
     * @param id the identifier
     * @return request center entity
     */
    CenterEO getCenter(final int id);

    /**
     * Get all relationship for combo box on creation of new employees
     *
     * @return list of all type relationship entities
     */
    List<TypeRelationshipEO> getAllTypeRelationship();
    
    /**
     * Get relationship according id
     *
     * @param id the identifier
     * @return type relationship entity
     */
    TypeRelationshipEO getTypeRelationship(final int id);

    
}
