package cz.cca.training.dao;

import cz.cca.training.entity.CenterEO;
import cz.cca.training.entity.EmployeeEO;
import cz.cca.training.entity.TypeRelationshipEO;
import cz.cca.training.utils.ResolveException;
import java.util.List;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

/**
 * <p>
 * Title: {@link EmployeeDAOBean}
 * </p>
 * <p>
 * Description: DAO for work with employees
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 3. 2015 14:28:43
 */
@Stateless
public class EmployeeDAOBean implements EmployeeDAO {

    @PersistenceContext
    private EntityManager entityManager;

    @Override
    public void saveEmployee(final EmployeeEO entity) {
        try {
            entityManager.persist(entity);
        }
        catch (RuntimeException re) {
            ResolveException.printException(re, "Connection to database failed!");
        }
    }
    @Override
    public void deleteEmployee(final EmployeeEO entity) {
        entityManager.remove(
            entityManager.getReference(
                 EmployeeEO.class,
                 entity.getIdEmployee()));
    }

    @Override
    public EmployeeEO updateEmployee(final EmployeeEO entity) {
        return entityManager.merge(entity);
    }

    @Override
    public EmployeeEO getEmployee(final int id) {
        return entityManager.find(EmployeeEO.class, id);
    }

    @Override
    public List<EmployeeEO> getAllEmployees() {
        return entityManager
                 .createNamedQuery(
                    EmployeeEO.ALL,
                    EmployeeEO.class)
                        .getResultList();
    }

    @Override
    public List<CenterEO> getAllCenter() {
        return entityManager
                .createNamedQuery(
                    CenterEO.ALL,
                    CenterEO.class)
                        .getResultList();
    }

  
    @Override
    public List<TypeRelationshipEO> getAllTypeRelationship() {
        return entityManager
            .createNamedQuery(
                TypeRelationshipEO.ALL,
                TypeRelationshipEO.class)
                    .getResultList();
    }

    @Override
    public List<EmployeeEO> getAllEmployeesForBrowse() {
        return entityManager
                 .createNamedQuery(
                    EmployeeEO.BROWSE_ALL,
                    EmployeeEO.class)
                        .getResultList();
    }

    @Override
    public CenterEO getCenter(int id) {
       return entityManager.find(CenterEO.class, id);
    }

    @Override
    public TypeRelationshipEO getTypeRelationship(int id) {
        return entityManager.find(TypeRelationshipEO.class, id);
    }

    
 
}