package cz.cca.training.dao;

import cz.cca.training.entity.CurrencyEO;
import cz.cca.training.entity.RealizationActionEO;
import cz.cca.training.entity.StatusActionEO;
import cz.cca.training.entity.UnitMeasureEO;
import java.util.List;

/**
 * <p>
 * Title: {@link RealizationActionDAO}
 * </p>
 * <p>
 * Description: Interface with necessary methods for basic work about realization action.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 26. 3. 2015 11:44:43
 */
public interface RealizationActionDAO {
    
     /**
     * @param entity realization action entity
     */
    void saveRealizationAction(final RealizationActionEO entity);

    /**
     * @param entity realization action entity
     */
    void deleteRealizationAction(final RealizationActionEO entity);

    /**
     * @param entity realization entity
     * @return result about updated entity 
     */
    RealizationActionEO updateRealizationAction(final RealizationActionEO entity);

    /**
     * Get realization action according the identifier
     * 
     * @param id the identifier registration
     * @return required registration
     */
    RealizationActionEO getRealizationAction(final int id);

    /**
     * Get all realization actions.
     *
     * @return list of all realization entities
     */
    List<RealizationActionEO> getAllRealizationAction();

    /**
     * Get currency for combo box on creation of new realization action
     * 
     * @return list of currency
     */
    List<CurrencyEO> getCurrencyList();

    
    /**
     * Get units measures for combo box on creation of new realization action
     * 
     * @return list of unit measures
     */
    List<UnitMeasureEO> getUnitMeasureList();

     /**
     * Get status for combo box on creation of new realization action
     * 
     * @return list of status actions
     */
    List<StatusActionEO> getStatusActionList();
    
    /**
     * Get currency according id
     * 
     * @param id the identifier
     * @return request currency
     */
    CurrencyEO getCurrency(final int id);

    
    /**
     * Get units measures according id
     * 
     * @param id the identifier
     * @return request unit measure
     */
    UnitMeasureEO getUnitMeasure(final int id);

     /**
     * Get status according id
     * 
     * @param id the identifier
     * @return request status action
     */
    StatusActionEO getStatusAction(final int id);
}
