package cz.cca.training.dao;

import cz.cca.training.entity.CurrencyEO;
import cz.cca.training.entity.RealizationActionEO;
import cz.cca.training.entity.StatusActionEO;
import cz.cca.training.entity.UnitMeasureEO;
import cz.cca.training.utils.ResolveException;
import java.util.List;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;


/**
 * <p>
 * Title: {@link RealizationActionDAO}
 * </p>
 * <p>
 * Description: DAO for basic work with realization action
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 3. 2015 16:34:39
 */
@Stateless
public class RealizationActionDAOBean implements RealizationActionDAO {

    @PersistenceContext
    private EntityManager entityManager;

    @Override
    public void saveRealizationAction(final RealizationActionEO entity) {
        try {
            entityManager.persist(entity);
        }
        catch (RuntimeException re) {
            ResolveException.printException(re, "Connection to database failed!");
        }
    }

    @Override
    public void deleteRealizationAction(final RealizationActionEO entity) {
        entityManager.remove(
            entityManager.getReference(
                 RealizationActionEO.class,
                 entity.getIdRealization()));
    }
    
    @Override
    public RealizationActionEO updateRealizationAction(final RealizationActionEO entity) {
        return entityManager.merge(entity);
    }

    @Override
    public RealizationActionEO getRealizationAction(final int id) {
        return entityManager.find(RealizationActionEO.class, id);
    }
    
    @Override
    public List<RealizationActionEO> getAllRealizationAction() {
         return entityManager
                .createNamedQuery(
                   RealizationActionEO.ALL,
                   RealizationActionEO.class)
                       .getResultList();
    }

   @Override
    public List<CurrencyEO> getCurrencyList() {
        return entityManager
                .createNamedQuery(
                   CurrencyEO.ALL,
                   CurrencyEO.class)
                       .getResultList();
    }

    @Override
    public List<UnitMeasureEO> getUnitMeasureList() {
        return entityManager
                .createNamedQuery(
                   UnitMeasureEO.ALL,
                   UnitMeasureEO.class)
                       .getResultList();
    }

    @Override
    public List<StatusActionEO> getStatusActionList() {
        return entityManager
                .createNamedQuery(
                    StatusActionEO.ALL,
                    StatusActionEO.class)
                        .getResultList();
    }

    @Override
    public CurrencyEO getCurrency(final int id) {
        return entityManager.find(CurrencyEO.class, id);
    }

    @Override
    public UnitMeasureEO getUnitMeasure(final int id) {
        return entityManager.find(UnitMeasureEO.class, id);
    }

    @Override
    public StatusActionEO getStatusAction(final int id) {
        return entityManager.find(StatusActionEO.class, id);
    }

}
