package cz.cca.training.dao;

import cz.cca.training.entity.ExpressionEO;
import cz.cca.training.entity.RegistrationEO;
import cz.cca.training.entity.StatusRegistrationEO;
import java.util.List;

/**
 * <p>
 * Title: {@link RegistrationDAO}
 * </p>
 * <p>
 * Description: Interface with necessary methods for basic work about registration.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 26. 3. 2015 11:43:23
 */
public interface RegistrationDAO {
    
     /**
     * @param entity registration entity
     */
    void saveRegistration(final RegistrationEO entity);

    /**
     * @param entity registration entity
     */
    void deleteRegistration(final RegistrationEO entity);

    /**
     * @param entity registration entity
     * @return result about updated entity 
     */
    RegistrationEO updateRegistration(final RegistrationEO entity);

    /**
     * Get detail registration according the identifier
     * 
     * @param id the identifier registration
     * @return required registration
     */ 
    RegistrationEO getRegistration(final int id);

    /**
     * Get all registration actions.
     *
     * @return list of all registration entities
     */
    List<RegistrationEO> getAllRegistration();

    /**
     * Get status registration for combo box on creation of registration on action
     * 
     * @return list of status registration
     */
    List<StatusRegistrationEO> getStatusRegistrationList();

    /**
     * Get expression student for combo box on creation of realization on action
     * 
     * @return list of expression
     */
    List<ExpressionEO> getExpressionStudentList();
    
    
    /**
     * Get status registration according id
     * 
     * @param id the identifier
     * @return request status registration
     */
    StatusRegistrationEO getStatusRegistration(final int id);

    /**
     * Get expression student according id
     *   
     * @param id the identifier
     * @return request expression
     */
    ExpressionEO getExpressionStudent(final int id);
}
