package cz.cca.training.dao;

import cz.cca.training.entity.ExpressionEO;
import cz.cca.training.entity.RegistrationEO;
import cz.cca.training.entity.StatusRegistrationEO;
import cz.cca.training.utils.ResolveException;
import java.util.List;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

/**
 * <p>
 * Title: {@link ActionDAOBean}
 * </p>
 * <p>
 * Description: DAO for basic work with user's registrations
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 25. 3. 2015 16:23:45
 */
@Stateless
public class RegistrationDAOBean implements RegistrationDAO {

    @PersistenceContext
    private EntityManager entityManager;

    @Override
    public void saveRegistration(final RegistrationEO entity) {
        try {
            entityManager.persist(entity);
        }
        catch (RuntimeException re) {
            ResolveException.printException(re, "Connection to database failed!");
        }
    }

    @Override
    public void deleteRegistration(final RegistrationEO entity) {
        entityManager.remove(
            entityManager.getReference(
                 RegistrationEO.class,
                 entity.getIdRegistration()));
    }

    @Override
    public RegistrationEO updateRegistration(final RegistrationEO entity) {
        return entityManager.merge(entity);
    }

    @Override
    public RegistrationEO getRegistration(final int id) {
        return entityManager.find(RegistrationEO.class, id);
    }

    @Override
    public List<RegistrationEO> getAllRegistration() {
        return entityManager
            .createNamedQuery(
                RegistrationEO.ALL,
                RegistrationEO.class)
                    .getResultList();
    }

    @Override
    public List<StatusRegistrationEO> getStatusRegistrationList() {
        return entityManager
            .createNamedQuery(
                StatusRegistrationEO.ALL,
                StatusRegistrationEO.class)
                 .getResultList();
    }

    @Override
    public List<ExpressionEO> getExpressionStudentList() {
        return entityManager
            .createNamedQuery(
                ExpressionEO.ALL,
                ExpressionEO.class)
                    .getResultList();
    }

    @Override
    public StatusRegistrationEO getStatusRegistration(int id) {
         return entityManager.find(StatusRegistrationEO.class, id);
    }

    @Override
    public ExpressionEO getExpressionStudent(int id) {
         return entityManager.find(ExpressionEO.class, id);
    }

}
