package cz.cca.training.entity;

import java.io.Serializable;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Lob;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * <p>
 * Title: {@link ActionEO}
 * </p>
 * <p>
 * Description: The persistent class for the cca_action database table.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 3. 2015 14:42:09
 */
@Entity
@Table(name = "cca_action")
@NamedQueries({
    @NamedQuery(name = "ActionEO.all", query = "SELECT action FROM ActionEO action") })
public class ActionEO implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String ALL = "ActionEO.all";

    @Id
    @Column(name = "id_action")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private int idAction;

    @Column(name = "code_action")
    private String codeAction;

    @Lob
    private String description;

    private String guarantee;

    @Column(name = "name_action")
    private String nameAction;

    @Lob
    private String note;

    // bi-directional many-to-one association to CcaRealizationActionEO
    @OneToMany(mappedBy = "ccaAction")
    private List<RealizationActionEO> ccaRealizationActions;

    public ActionEO() {
    }

    public int getIdAction() {
        return this.idAction;
    }

    public void setIdAction(int idAction) {
        this.idAction = idAction;
    }

    public String getCodeAction() {
        return this.codeAction;
    }

    public void setCodeAction(String codeAction) {
        this.codeAction = codeAction;
    }

    public String getDescription() {
        return this.description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getGuarantee() {
        return this.guarantee;
    }

    public void setGuarantee(String guarantee) {
        this.guarantee = guarantee;
    }

    public String getNameAction() {
        return this.nameAction;
    }

    public void setNameAction(String nameAction) {
        this.nameAction = nameAction;
    }

    public String getNote() {
        return this.note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public List<RealizationActionEO> getCcaRealizationActions() {
        return this.ccaRealizationActions;
    }

    public void setCcaRealizationActions(
            List<RealizationActionEO> ccaRealizationActions) {
        this.ccaRealizationActions = ccaRealizationActions;
    }

    public RealizationActionEO addCcaRealizationAction(
            RealizationActionEO ccaRealizationAction) {
        getCcaRealizationActions().add(ccaRealizationAction);
        ccaRealizationAction.setCcaAction(this);

        return ccaRealizationAction;
    }

    public RealizationActionEO removeCcaRealizationAction(
            RealizationActionEO ccaRealizationAction) {
        getCcaRealizationActions().remove(ccaRealizationAction);
        ccaRealizationAction.setCcaAction(null);

        return ccaRealizationAction;
    }

}