package cz.cca.training.entity;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * <p>
 * Title: {@link EmployeeEO}
 * </p>
 * <p>
 * Description: The persistent class for the cca_employees database table.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 3. 2015 14:43:21
 */
@Entity
@Table(name = "cca_employees")
@NamedQueries({
    @NamedQuery(name = "EmployeeEO.all", query = "SELECT employee FROM EmployeeEO employee"),
    @NamedQuery(name = "EmployeeEO.browseAll", query = "SELECT emp FROM EmployeeEO emp LEFT JOIN emp.ccaCenter center "
        + "LEFT JOIN emp.ccaTypeRelationship relation ORDER BY emp.personalCode")})
public class EmployeeEO implements Serializable {

    private static final long serialVersionUID = 1L;
    
    public static final String ALL = "EmployeeEO.all";
    public static final String BROWSE_ALL = "EmployeeEO.browseAll";
    
    @Id
    @Column(name = "id_employee")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private int idEmployee;

    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "date_rating")
    private Date dateRating;

    @Lob
    @Column(name = "description")
    private String description;

    @Column(name = "email_address")
    private String emailAddress;

    @Column(name = "first_name")
    private String firstName;

    @Column(name = "id_leader")
    private int idLeader;

    @Column(name = "personal_code")
    private String personalCode;

    @Column(name = "surname")
    private String surname;

    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "validity_contract")
    private Date validityContract;

    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "validity_from")
    private Date validityFrom;

    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "validity_into")
    private Date validityInto;

    // bi-directional many-to-one association to CcaCenterEO
    @ManyToOne
    @JoinColumn(name = "id_center")
    private CenterEO ccaCenter;

    // bi-directional many-to-one association to CcaTypeRelationshipEO
    @ManyToOne
    @JoinColumn(name = "id_type_relationship")
    private TypeRelationshipEO ccaTypeRelationship;

    // bi-directional many-to-one association to CcaRegistrationEO
    @OneToMany(mappedBy = "ccaEmployee")
    private List<RegistrationEO> ccaRegistrations;

    public EmployeeEO() {}

    public int getIdEmployee() {
            return this.idEmployee;
    }

    public void setIdEmployee(int idEmployee) {
            this.idEmployee = idEmployee;
    }

    public Date getDateRating() {
            return this.dateRating;
    }

    public void setDateRating(Date dateRating) {
            this.dateRating = dateRating;
    }

    public String getDescription() {
            return this.description;
    }

    public void setDescription(String description) {
            this.description = description;
    }

    public String getEmailAddress() {
            return this.emailAddress;
    }

    public void setEmailAddress(String emailAddress) {
            this.emailAddress = emailAddress;
    }

    public String getFirstName() {
            return this.firstName;
    }

    public void setFirstName(String firstName) {
            this.firstName = firstName;
    }

    public int getIdLeader() {
            return this.idLeader;
    }

    public void setIdLeader(int idLeader) {
            this.idLeader = idLeader;
    }

    public String getPersonalCode() {
            return this.personalCode;
    }

    public void setPersonalCode(String personalCode) {
            this.personalCode = personalCode;
    }

    public String getSurname() {
            return this.surname;
    }

    public void setSurname(String surname) {
            this.surname = surname;
    }

    public Date getValidityContract() {
            return this.validityContract;
    }

    public void setValidityContract(Date validityContract) {
            this.validityContract = validityContract;
    }

    public Date getValidityFrom() {
            return this.validityFrom;
    }

    public void setValidityFrom(Date validityFrom) {
            this.validityFrom = validityFrom;
    }

    public Date getValidityInto() {
            return this.validityInto;
    }

    public void setValidityInto(Date validityInto) {
            this.validityInto = validityInto;
    }

    public CenterEO getCcaCenter() {
            return this.ccaCenter;
    }

    public void setCcaCenter(CenterEO ccaCenter) {
            this.ccaCenter = ccaCenter;
    }

    public TypeRelationshipEO getCcaTypeRelationship() {
            return this.ccaTypeRelationship;
    }

    public void setCcaTypeRelationship(TypeRelationshipEO ccaTypeRelationship) {
            this.ccaTypeRelationship = ccaTypeRelationship;
    }

    public List<RegistrationEO> getCcaRegistrations() {
            return this.ccaRegistrations;
    }

    public void setCcaRegistrations(List<RegistrationEO> ccaRegistrations) {
            this.ccaRegistrations = ccaRegistrations;
    }

    public RegistrationEO addCcaRegistration(RegistrationEO ccaRegistration) {
            getCcaRegistrations().add(ccaRegistration);
            ccaRegistration.setCcaEmployee(this);

            return ccaRegistration;
    }

    public RegistrationEO removeCcaRegistration(RegistrationEO ccaRegistration) {
            getCcaRegistrations().remove(ccaRegistration);
            ccaRegistration.setCcaEmployee(null);

            return ccaRegistration;
    }

    @Override
    public String toString() {
        return "EmployeeEO [idEmployee=" + idEmployee + ", dateRating="
                + dateRating + ", description=" + description
                + ", emailAddress=" + emailAddress + ", firstName=" + firstName
                + ", idLeader=" + idLeader + ", personalCode=" + personalCode
                + ", surname=" + surname + ", validityContract="
                + validityContract + ", validityFrom=" + validityFrom
                + ", validityInto=" + validityInto + ", ccaCenter=" + ccaCenter.getIdCenter()
                + ", ccaTypeRelationship=" + ccaTypeRelationship.getIdTypeRelationship()
                + ", ccaRegistrations=" + ccaRegistrations + "]";
    }

}