package cz.cca.training.entity;

import java.io.Serializable;
import java.util.Date;
import java.util.List;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * <p>
 * Title: {@link RealizationActionEO}
 * </p>
 * <p>
 * Description: The persistent class for the cca_realization_action database table.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 3. 2015 14:44:35
 */
@Entity
@Table(name = "cca_realization_action")
@NamedQueries({
    @NamedQuery(name = "RealizationActionEO.all", query = "SELECT realization FROM RealizationActionEO realization")})
public class RealizationActionEO implements Serializable {
    private static final long serialVersionUID = 1L;

    public static final String ALL = "RealizationActionEO.all";

    @Id
    @Column(name = "id_realization")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private int idRealization;

    @Column(name = "code_action")
    private String codeAction;

    @Column(name = "compulsory_ratings")
    private boolean compulsoryRatings;

    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "date_realization")
    private Date dateRealization;

    @Lob
    private String description;

    private String guarantee;

    @Column(name = "intended_for")
    private String intendedFor;

    private int length;

    @Column(name = "max_participants")
    private int maxParticipants;

    @Column(name = "min_participants")
    private int minParticipants;

    @Column(name = "name_action")
    private String nameAction;

    @Lob
    private String note;

    private String place;

    private int price;

    @Column(name = "publish_rating")
    private boolean publishRating;

    @Column(name = "single_price")
    private boolean singlePrice;

    private String trainer;

    @Column(name = "transmission_report")
    private boolean transmissionReport;

    // bi-directional many-to-one association to CcaActionEO
    @ManyToOne
    @JoinColumn(name = "id_action")
    private ActionEO ccaAction;

    // bi-directional many-to-one association to CcaRegistrationEO
    @OneToMany(mappedBy = "ccaRealizationAction")
    private List<RegistrationEO> ccaRegistrations;

    // bi-directional many-to-one association to CcaStatusActionEO
    @ManyToOne
    @JoinColumn(name = "id_status_action")
    private StatusActionEO ccaStatusAction;

    // bi-directional many-to-one association to CcaUnitMeasureEO
    @ManyToOne
    @JoinColumn(name = "id_unit_measure")
    private UnitMeasureEO ccaUnitMeasure;

    // bi-directional many-to-one association to CcaCurrencyEO
    @ManyToOne
    @JoinColumn(name = "id_currency")
    private CurrencyEO ccaCurrency;

    public RealizationActionEO() {}

    public int getIdRealization() {
            return this.idRealization;
    }

    public void setIdRealization(int idRealization) {
            this.idRealization = idRealization;
    }

    public String getCodeAction() {
            return this.codeAction;
    }

    public void setCodeAction(String codeAction) {
            this.codeAction = codeAction;
    }

    public boolean getCompulsoryRatings() {
            return this.compulsoryRatings;
    }

    public void setCompulsoryRatings(boolean compulsoryRatings) {
            this.compulsoryRatings = compulsoryRatings;
    }

    public Date getDateRealization() {
            return this.dateRealization;
    }

    public void setDateRealization(Date dateRealization) {
            this.dateRealization = dateRealization;
    }

    public String getDescription() {
            return this.description;
    }

    public void setDescription(String description) {
            this.description = description;
    }

    public String getGuarantee() {
            return this.guarantee;
    }

    public void setGuarantee(String guarantee) {
            this.guarantee = guarantee;
    }

    public String getIntendedFor() {
            return this.intendedFor;
    }

    public void setIntendedFor(String intendedFor) {
            this.intendedFor = intendedFor;
    }

    public int getLength() {
            return this.length;
    }

    public void setLength(int length) {
            this.length = length;
    }

    public int getMaxParticipants() {
            return this.maxParticipants;
    }

    public void setMaxParticipants(int maxParticipants) {
            this.maxParticipants = maxParticipants;
    }

    public int getMinParticipants() {
            return this.minParticipants;
    }

    public void setMinParticipants(int minParticipants) {
            this.minParticipants = minParticipants;
    }

    public String getNameAction() {
            return this.nameAction;
    }

    public void setNameAction(String nameAction) {
            this.nameAction = nameAction;
    }

    public String getNote() {
            return this.note;
    }

    public void setNote(String note) {
            this.note = note;
    }

    public String getPlace() {
            return this.place;
    }

    public void setPlace(String place) {
            this.place = place;
    }

    public int getPrice() {
            return this.price;
    }

    public void setPrice(int price) {
            this.price = price;
    }

    public boolean getPublishRating() {
            return this.publishRating;
    }

    public void setPublishRating(boolean publishRating) {
            this.publishRating = publishRating;
    }

    public boolean getSinglePrice() {
            return this.singlePrice;
    }

    public void setSinglePrice(boolean singlePrice) {
            this.singlePrice = singlePrice;
    }

    public String getTrainer() {
            return this.trainer;
    }

    public void setTrainer(String trainer) {
            this.trainer = trainer;
    }

    public boolean getTransmissionReport() {
            return this.transmissionReport;
    }

    public void setTransmissionReport(boolean transmissionReport) {
            this.transmissionReport = transmissionReport;
    }

    public ActionEO getCcaAction() {
            return this.ccaAction;
    }

    public void setCcaAction(ActionEO ccaAction) {
            this.ccaAction = ccaAction;
    }

    public List<RegistrationEO> getCcaRegistrations() {
            return this.ccaRegistrations;
    }

    public void setCcaRegistrations(List<RegistrationEO> ccaRegistrations) {
            this.ccaRegistrations = ccaRegistrations;
    }

    public RegistrationEO addCcaRegistration(RegistrationEO ccaRegistration) {
            getCcaRegistrations().add(ccaRegistration);
            ccaRegistration.setCcaRealizationAction(this);

            return ccaRegistration;
    }

    public RegistrationEO removeCcaRegistration(RegistrationEO ccaRegistration) {
            getCcaRegistrations().remove(ccaRegistration);
            ccaRegistration.setCcaRealizationAction(null);

            return ccaRegistration;
    }

    public StatusActionEO getCcaStatusAction() {
            return this.ccaStatusAction;
    }

    public void setCcaStatusAction(StatusActionEO ccaStatusAction) {
            this.ccaStatusAction = ccaStatusAction;
    }

    public UnitMeasureEO getCcaUnitMeasure() {
            return this.ccaUnitMeasure;
    }

    public void setCcaUnitMeasure(UnitMeasureEO ccaUnitMeasure) {
            this.ccaUnitMeasure = ccaUnitMeasure;
    }

    public CurrencyEO getCcaCurrency() {
            return this.ccaCurrency;
    }

    public void setCcaCurrency(CurrencyEO ccaCurrency) {
            this.ccaCurrency = ccaCurrency;
    }

}