package cz.cca.training.entity;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * <p>
 * Title: {@link RegistrationEO}
 * </p>
 * <p>
 * Description: The persistent class for the cca_registration database table.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 3. 2015 14:44:22
 */
@Entity
@Table(name = "cca_registration")
@NamedQueries({
    @NamedQuery(name = "RegistrationEO.all", query = "SELECT registration FROM RegistrationEO registration")})
public class RegistrationEO implements Serializable {
    private static final long serialVersionUID = 1L;

        public static final String ALL = "RegistrationEO.all";
        
    @Id
    @Column(name = "id_registration")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private int idRegistration;

    @Column(name = "created_registration")
    private String createdRegistration;

    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "date_registration")
    private Date dateRegistration;

    @Lob
    private String note;

    // bi-directional many-to-one association to CcaEmployeeEO
    @ManyToOne
    @JoinColumn(name = "id_employee")
    private EmployeeEO ccaEmployee;

    // bi-directional many-to-one association to CcaExpressionEO
    @ManyToOne
    @JoinColumn(name = "id_expression_student")
    private ExpressionEO ccaExpression;

    // bi-directional many-to-one association to CcaRealizationActionEO
    @ManyToOne
    @JoinColumn(name = "id_realization")
    private RealizationActionEO ccaRealizationAction;

    // bi-directional many-to-one association to CcaStatusRegistrationEO
    @ManyToOne
    @JoinColumn(name = "id_status_registration")
    private StatusRegistrationEO ccaStatusRegistration;

    public RegistrationEO() {}

    public int getIdRegistration() {
        return this.idRegistration;
    }

    public void setIdRegistration(int idRegistration) {
        this.idRegistration = idRegistration;
    }

    public String getCreatedRegistration() {
        return this.createdRegistration;
    }

    public void setCreatedRegistration(String createdRegistration) {
        this.createdRegistration = createdRegistration;
    }

    public Date getDateRegistration() {
        return this.dateRegistration;
    }

    public void setDateRegistration(Date dateRegistration) {
        this.dateRegistration = dateRegistration;
    }

    public String getNote() {
        return this.note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public EmployeeEO getCcaEmployee() {
        return this.ccaEmployee;
    }

    public void setCcaEmployee(EmployeeEO ccaEmployee) {
        this.ccaEmployee = ccaEmployee;
    }

    public ExpressionEO getCcaExpression() {
        return this.ccaExpression;
    }

    public void setCcaExpression(ExpressionEO ccaExpression) {
        this.ccaExpression = ccaExpression;
    }

    public RealizationActionEO getCcaRealizationAction() {
        return this.ccaRealizationAction;
    }

    public void setCcaRealizationAction(RealizationActionEO ccaRealizationAction) {
        this.ccaRealizationAction = ccaRealizationAction;
    }

    public StatusRegistrationEO getCcaStatusRegistration() {
        return this.ccaStatusRegistration;
    }

    public void setCcaStatusRegistration(StatusRegistrationEO ccaStatusRegistration) {
        this.ccaStatusRegistration = ccaStatusRegistration;
    }

}