package cz.cca.training.rest;

import cz.cca.training.dao.ActionDAO;
import cz.cca.training.entity.ActionEO;
import cz.cca.training.rest.response.ActionJSON;
import cz.cca.training.rest.response.ActionNewJSON;
import cz.cca.training.rest.response.ActionUpdateJSON;
import cz.cca.training.utils.MapFromJson;
import cz.cca.training.utils.MapToJsonObject;
import java.util.LinkedList;
import java.util.List;
import javax.inject.Inject;
import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Response;

/**
 * <p>
 * Title: {@link ActionREST}
 * </p>
 * <p>
 * Description: Rest service for basic work about actions with necessary methods.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 25. 3. 2015 11:48:53
 */
@Path("action")
public class ActionREST {

    @Inject
    private ActionDAO dao;

    /**
     * Get all action (example URI: http://localhost:8080/training/api/action)
     * @return list of action in JSON
     */
    @GET
    @Produces("application/json")
    public List<ActionJSON> getActionList() {

        List<ActionEO> listActionEO = dao.getAllAction();
        List<ActionJSON> listActionJSON = new LinkedList<ActionJSON>();

        for (ActionEO actionEO : listActionEO) {
            listActionJSON.add(MapToJsonObject.mapToActionJSON(actionEO));
        }

        return listActionJSON;
    }

    /**
     * Get one action (detail) according the identifier (example URI: http://localhost:8080/training/api/action/detail/3)
     * @param id the identifier
     * @return action in JSON
     */
    @GET
    @Path("/detail/{id}") 
    @Produces("application/json")
    public ActionJSON getAction(@PathParam("id") int id) {
        return MapToJsonObject.mapToActionJSON(this.dao.getAction(id));
    }
    
    /**
     * Delete action according id (example URI: http://localhost:8080/training/api/action/delete/3).
     * @param id the identifier
     */
    @DELETE
    @Path("/delete/{id}")
    public void deleteAction(@PathParam("id") int id) {
       this.dao.deleteAction(this.dao.getAction(id));
    }
    
    /**
     * Insert new action (example URI: http://localhost:8080/training/api/action/create/).
     * @param action new action from PL
     * @return response (expected all is alright, that's why sending ok)
     */
    @PUT
    @Consumes("application/json")
    @Path("/create")
    public Response createAction(ActionNewJSON action) {
        this.dao.saveAction(MapFromJson.mapFromActionNewJSON(action));
        return Response.ok().build();
    }
    
    /**
     * Update old action (example URI: http://localhost:8080/training/api/action/).
     * @param action new action's values from PL
     * @return response (expected all is alright, that's why sending ok)
     */
    @POST
    @Consumes("application/json") 
    public Response updateAction(ActionUpdateJSON action) {
        this.dao.updateAction(MapFromJson.mapFromActionUpdateJSON(this.dao.getAction(action.getIdAction()),action));
        return Response.ok().build();
    }
    

}
