/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package cz.cca.training.rest;

import cz.cca.training.dao.ActionDAO;
import cz.cca.training.dao.RealizationActionDAO;
import cz.cca.training.entity.RealizationActionEO;
import cz.cca.training.rest.response.RealizationActionJSON;
import cz.cca.training.rest.response.RealizationActionNewJSON;
import cz.cca.training.rest.response.RealizationActionUpdateJSON;
import cz.cca.training.utils.MapFromJson;
import cz.cca.training.utils.MapToJsonObject;
import java.util.LinkedList;
import java.util.List;
import javax.inject.Inject;
import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Response;

/**
 * <p>
 * Title: {@link RealizationActionREST}
 * </p>
 * <p>
 * Description: Rest service to work with realization actions.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 4. 2015 16:25:45
 */
@Path("realizationAction")
public class RealizationActionREST {
    
    @Inject
    private RealizationActionDAO dao;
    
    @Inject
    private ActionDAO actionDao;
 
    /**
     * Get all realizationAction (example URI: http://localhost:8080/training/api/realizationAction)
     * @return list of realizationAction in JSON
     */
    @GET
    @Produces("application/json")
    public List<RealizationActionJSON> getRealizationActionList() {

        List<RealizationActionEO> listEO = this.dao.getAllRealizationAction();
        List<RealizationActionJSON> listJSON = new LinkedList<RealizationActionJSON>();

        for (RealizationActionEO item : listEO) {
            listJSON.add(MapToJsonObject.mapToRealizationActionJSON(item));
        }

        return listJSON;
    }
    
    /**
     * Get one realizationAction (detail) according the identifier (example URI: http://localhost:8080/training/api/realizationAction/detail/3)
     * @param id the identifier
     * @return realizationAction in JSON
     */
    @GET
    @Path("/detail/{id}") 
    @Produces("application/json")
    public RealizationActionJSON getRealizationAction(@PathParam("id") int id) {
        return MapToJsonObject.mapToRealizationActionJSON(this.dao.getRealizationAction(id));
    }
    
    /**
     * Delete realizationAction according id (example URI: http://localhost:8080/training/api/realizationAction/delete/3).
     * @param id the identifier
     */
    @DELETE
    @Path("/delete/{id}")
    public void deleteRealizationAction(@PathParam("id") int id) {
       this.dao.deleteRealizationAction(this.dao.getRealizationAction(id));
    }
    
    /**
     * Insert new realizationAction (example URI: http://localhost:8080/training/api/realizationAction/create/).
     * @param realAction new realizationAction from PL
     * @return response (expected all is alright, that's why sending ok)
     */
    @PUT
    @Consumes("application/json")
    @Path("/create")
    public Response createRealizationAction(RealizationActionNewJSON realAction) {
        this.dao.saveRealizationAction(MapFromJson.mapFromRealizationNewJSON(realAction, 
                this.actionDao.getAction(realAction.getIdAction()),
                this.dao.getUnitMeasure(realAction.getIdUnitMeasure()),
                this.dao.getStatusAction(realAction.getIdStatusAction()),
                this.dao.getCurrency(realAction.getIdCurrency())));
        return Response.ok().build();
    }
    
    /**
     * Update old realizationAction (example URI: http://localhost:8080/training/api/realizationAction/).
     * @param realAction new realizationAction's values from PL
     * @return response (expected all is alright, that's why sending ok)
     */
    @POST
    @Consumes("application/json") 
    public Response updateRealizationAction(RealizationActionUpdateJSON realAction) {
        this.dao.updateRealizationAction(MapFromJson.mapFromRealizationUpdateJSON(this.dao.getRealizationAction(realAction.getIdRealizationAction()),realAction, 
                this.actionDao.getAction(realAction.getIdAction()),
                this.dao.getUnitMeasure(realAction.getIdUnitMeasure()),
                this.dao.getStatusAction(realAction.getIdStatusAction()),
                this.dao.getCurrency(realAction.getIdCurrency())));
        return Response.ok().build();
    }
}
