/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package cz.cca.training.rest;

import cz.cca.training.dao.EmployeeDAO;
import cz.cca.training.dao.RealizationActionDAO;
import cz.cca.training.dao.RegistrationDAO;
import cz.cca.training.entity.EmployeeEO;
import cz.cca.training.entity.ExpressionEO;
import cz.cca.training.entity.RealizationActionEO;
import cz.cca.training.entity.RegistrationEO;
import cz.cca.training.entity.StatusRegistrationEO;
import cz.cca.training.rest.response.RegistrationJSON;
import cz.cca.training.rest.response.RegistrationNewJSON;
import cz.cca.training.rest.response.RegistrationUpdateJSON;
import cz.cca.training.utils.MapFromJson;
import cz.cca.training.utils.MapToJsonObject;
import java.util.LinkedList;
import java.util.List;
import javax.inject.Inject;
import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Response;

/**
 * <p>
 * Title: {@link RegistrationREST}
 * </p>
 * <p>
 * Description: Rest service to work with registrations.
 * </p>
 * <p>
 * Copyright: Copyright (c) 2015 Kosek David
 * </p>
 * <p>
 * ZCU KIV/FAV
 * </p>
 *
 * @author david.kosek A14N0132P
 * @date 24. 4. 2015 16:26:43
 */
@Path("registration")
public class RegistrationREST {
    
    
    @Inject
    private RegistrationDAO dao;
    
    @Inject
    private EmployeeDAO employeeDao;
    
    @Inject
    private RealizationActionDAO realizationDao;

    /**
     * Get all registration (example URI: http://localhost:8080/training/api/registration)
     * @return list of registration in JSON
     */    
    @GET
    @Produces("application/json")
    public List<RegistrationJSON> getRegistrationList() {

        List<RegistrationEO> listEO = this.dao.getAllRegistration();
        List<RegistrationJSON> listJSON = new LinkedList<RegistrationJSON>();

        for (RegistrationEO item : listEO) {
            EmployeeEO emp = this.employeeDao.getEmployee(item.getCcaEmployee().getIdEmployee());
            ExpressionEO exp =  this.dao.getExpressionStudent(item.getCcaExpression().getIdExpression());
            StatusRegistrationEO status = this.dao.getStatusRegistration(item.getCcaStatusRegistration().getIdStatusRegistration());
            RealizationActionEO realization = this.realizationDao.getRealizationAction(item.getCcaRealizationAction().getIdRealization());
            
            listJSON.add(MapToJsonObject.mapToRegistrationJSON(item, emp, exp, status, realization));
        }

        return listJSON;
    }
    
    /**
     * Get one registration (detail) according the identifier (example URI: http://localhost:8080/training/api/registration/detail/3)
     * @param id the identifier
     * @return registration in JSON
     */
    @GET
    @Path("/detail/{id}") 
    @Produces("application/json")
    public RegistrationJSON getRegistration(@PathParam("id") int id) {
        RegistrationEO registration = this.dao.getRegistration(id);
        
        EmployeeEO emp = this.employeeDao.getEmployee(registration.getCcaEmployee().getIdEmployee());
        ExpressionEO exp =  this.dao.getExpressionStudent(registration.getCcaExpression().getIdExpression());
        StatusRegistrationEO status = this.dao.getStatusRegistration(registration.getCcaStatusRegistration().getIdStatusRegistration());
        RealizationActionEO realization = this.realizationDao.getRealizationAction(registration.getCcaRealizationAction().getIdRealization());
                
        return MapToJsonObject.mapToRegistrationJSON(registration, emp, exp, status, realization);
    }
    
    /**
     * Delete registration according id (example URI: http://localhost:8080/training/api/registration/delete/3).
     * @param id the identifier
     */ 
    @DELETE
    @Path("/delete/{id}")
    public void deleteRegistration(@PathParam("id") int id) {
       this.dao.deleteRegistration(this.dao.getRegistration(id));
    }
    
    /**
     * Insert new registration (example URI: http://localhost:8080/training/api/registration/create/).
     * @param registration new registration from PL
     * @return response (expected all is alright, that's why sending ok)
     */
    @PUT
    @Consumes("application/json")
    @Path("/create")
    public Response createRegistration(RegistrationNewJSON registration) {
        this.dao.saveRegistration(MapFromJson.mapFromRegistrationNewJSON(registration,
                this.employeeDao.getEmployee(registration.getIdEmployee()),
                this.dao.getExpressionStudent(registration.getIdExpression()),
                this.dao.getStatusRegistration(registration.getIdStatusRegistration()),
                this.realizationDao.getRealizationAction(registration.getIdRealizationAction())
                ));
        return Response.ok().build();
    }
    
    /**
     * Update old registration (example URI: http://localhost:8080/training/api/registration/).
     * @param registration new registration's values from PL
     * @return response (expected all is alright, that's why sending ok)
     */
    @POST
    @Consumes("application/json") 
    public Response updateRegistration(RegistrationUpdateJSON registration) {
        this.dao.updateRegistration(MapFromJson.mapFromRegistrationUpdateJSON(this.dao.getRegistration(registration.getIdRegistration()),registration,
                this.employeeDao.getEmployee(registration.getIdEmployee()),
                this.dao.getExpressionStudent(registration.getIdExpression()),
                this.dao.getStatusRegistration(registration.getIdStatusRegistration()),
                this.realizationDao.getRealizationAction(registration.getIdRealizationAction())
                ));
        return Response.ok().build();
    }
    
}
