package cz.cca.training.rest.filter;

import cz.cca.training.token.TokenManager;
import cz.cca.training.utils.AccessUser;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.container.ContainerRequestContext;
import javax.ws.rs.container.ContainerRequestFilter;
import javax.ws.rs.core.Response;
import java.io.IOException;

/**
 * Class for authentication of user
 */
public class AuthorizationFilter implements ContainerRequestFilter {

        private TokenManager tokenManager = TokenManager.getInstance();

        public void filter(ContainerRequestContext containerRequestContext) throws IOException {

            String token = "";

            if (containerRequestContext.getHeaders().containsKey("X-Token"))
                token = containerRequestContext.getHeaders().get("X-Token").get(0);

            String role;
            if ((role = tokenManager.getRole(token)) == null){
                throwWebApplicationException();
            }

            if (role.equals("user")) {
                String url =  containerRequestContext.getUriInfo().getAbsolutePath().getPath();

                url = url.replaceAll("\\d", "");
                url = url.substring(0, url.length() - 2) + url.substring(url.length() - 2).replace("/", "");

                String method = containerRequestContext.getMethod();
                if (AccessUser.haveAccess(url + ":" + method) == false) {
                    throwWebApplicationException();
                }
            }
        }

        private void throwWebApplicationException() {
            Response.ResponseBuilder builder = Response.status(Response.Status.UNAUTHORIZED);
            throw new WebApplicationException(builder.build());
        }
}
