package cz.cca.training.utils;

import cz.cca.training.entity.ActionEO;
import cz.cca.training.entity.CenterEO;
import cz.cca.training.entity.CurrencyEO;
import cz.cca.training.entity.EmployeeEO;
import cz.cca.training.entity.ExpressionEO;
import cz.cca.training.entity.RealizationActionEO;
import cz.cca.training.entity.RegistrationEO;
import cz.cca.training.entity.StatusActionEO;
import cz.cca.training.entity.StatusRegistrationEO;
import cz.cca.training.entity.TypeRelationshipEO;
import cz.cca.training.entity.UnitMeasureEO;
import cz.cca.training.rest.response.ActionJSON;
import cz.cca.training.rest.response.CenterJSON;
import cz.cca.training.rest.response.CurrencyJSON;
import cz.cca.training.rest.response.EmployeeJSON;
import cz.cca.training.rest.response.EmployeesBrowseJSON;
import cz.cca.training.rest.response.ExpressionJSON;
import cz.cca.training.rest.response.LeaderJSON;
import cz.cca.training.rest.response.RealizationActionJSON;
import cz.cca.training.rest.response.RegistrationJSON;
import cz.cca.training.rest.response.StatusActionJSON;
import cz.cca.training.rest.response.StatusRegistrationJSON;
import cz.cca.training.rest.response.TypeRelationshipJSON;
import cz.cca.training.rest.response.UnitMeasureJSON;

/**
 * Class mapping entity object to json object
 */
public class MapToJsonObject {

    public static ActionJSON mapToActionJSON(ActionEO actionEO) {
        ActionJSON actionJSON = new ActionJSON();

        actionJSON.setCodeAction(actionEO.getCodeAction());
        actionJSON.setDescription(actionEO.getDescription());
        actionJSON.setGuarantee(actionEO.getGuarantee());
        actionJSON.setNote(actionEO.getNote());
        actionJSON.setNameAction(actionEO.getNameAction());
        actionJSON.setIdAction(actionEO.getIdAction());

        return actionJSON;
    }
   

    public static EmployeeJSON mapToEmployeeJSON(EmployeeEO employeeEO) {
        EmployeeJSON employeeJSON = new EmployeeJSON();
                
        employeeJSON.setIdEmployee(employeeEO.getIdEmployee());
        employeeJSON.setDateRating(employeeEO.getDateRating() == null ? null : employeeEO.getDateRating());
        employeeJSON.setDescription(employeeEO.getDescription() == null ? null : employeeEO.getDescription());
        employeeJSON.setEmailAddress(employeeEO.getEmailAddress()  == null ? null : employeeEO.getEmailAddress());
        employeeJSON.setFirstName(employeeEO.getFirstName());
        employeeJSON.setIdLeader(employeeEO.getIdLeader());
        employeeJSON.setPersonalCode(employeeEO.getPersonalCode());
        employeeJSON.setSurname(employeeEO.getSurname());
        employeeJSON.setValidityContract(employeeEO.getValidityContract() == null ? null : employeeEO.getValidityContract());
        employeeJSON.setValidityFrom(employeeEO.getValidityFrom());
        employeeJSON.setValidityInto(employeeEO.getValidityInto() == null ? null : employeeEO.getValidityInto());
        employeeJSON.setCenter(employeeEO.getCcaCenter().getCodeCenter());
        employeeJSON.setTypeRelationship(employeeEO.getCcaTypeRelationship().getTypeRelationship());

        return employeeJSON;
    }
    
    public static EmployeesBrowseJSON mapToEmployeesBrowseJSON(EmployeeEO employeeEO, EmployeeEO leaderInfo) {
        EmployeesBrowseJSON newEmployee = new EmployeesBrowseJSON();
        
        newEmployee.setIdEmployee(employeeEO.getIdEmployee());
        newEmployee.setPersonalCode(employeeEO.getPersonalCode());
        newEmployee.setFirstName(employeeEO.getFirstName());
        newEmployee.setSurname(employeeEO.getSurname());
        newEmployee.setTypeRelationship(employeeEO.getCcaTypeRelationship().getTypeRelationship());
        newEmployee.setCenter(employeeEO.getCcaCenter().getCodeCenter());
        newEmployee.setLeaderInfo(leaderInfo.getPersonalCode()+" - "+leaderInfo.getFirstName()+" "+leaderInfo.getSurname());
        
        return newEmployee;
    }

    public static CenterJSON mapToCenterJSON(CenterEO ccaCenterEO) {
        CenterJSON centerJSON = new CenterJSON();

       /*  List<EmployeeJSON> employeeJSONList = new LinkedList<EmployeeJSON>();

       for(EmployeeEO employeeEO : ccaCenterEO.getCcaEmployees()) {
            employeeJSONList.add(mapToEmployeeJSON(employeeEO));
        }

        centerJSON.setCcaEmployees(employeeJSONList);*/
        centerJSON.setCodeCenter(ccaCenterEO.getCodeCenter());
        centerJSON.setFullNameCenter(centerJSON.getFullNameCenter());
        centerJSON.setIdCenter(ccaCenterEO.getIdCenter());

        return centerJSON;
    }

    public static TypeRelationshipJSON mapToTypeRelationshipJSON(TypeRelationshipEO typeRelationshipEO) {
        TypeRelationshipJSON typeRelationshipJSON = new TypeRelationshipJSON();

        typeRelationshipJSON.setAbbreviationRelationship(typeRelationshipEO.getAbbreviationRelationship());
        typeRelationshipJSON.setIdTypeRelationship(typeRelationshipEO.getIdTypeRelationship());
        typeRelationshipJSON.setTypeRelationship(typeRelationshipEO.getTypeRelationship());

        return typeRelationshipJSON;
    }
    
  
    public static RegistrationJSON mapToRegistrationJSON(RegistrationEO registrationEO, EmployeeEO emp, ExpressionEO exp, StatusRegistrationEO status, RealizationActionEO realization) {
        RegistrationJSON registrationJSON = new RegistrationJSON();

        registrationJSON.setCcaEmployee(mapToEmployeeJSON(emp));
        registrationJSON.setCcaExpression(mapToExpressionJSON(exp));
        registrationJSON.setCcaStatusRegistration(mapToStatusRegistrationJSON(status));
        
        registrationJSON.setIdRegistration(registrationEO.getIdRegistration());
        registrationJSON.setNote(registrationEO.getNote());
        registrationJSON.setDateRegistration(registrationEO.getDateRegistration());
        registrationJSON.setCreatedRegistration(registrationEO.getCreatedRegistration());

        registrationJSON.setRealizationAction(mapToRealizationActionJSON(realization));
                
        return registrationJSON;
    }

    public static StatusRegistrationJSON mapToStatusRegistrationJSON(StatusRegistrationEO statusRegistrationEO) {
        StatusRegistrationJSON statusRegistrationJSON = new StatusRegistrationJSON();

        statusRegistrationJSON.setIdStatusRegistration(statusRegistrationEO.getIdStatusRegistration());
        statusRegistrationJSON.setStatusRegistration(statusRegistrationEO.getStatusRegistration());

        return statusRegistrationJSON;
    }

    public static ExpressionJSON mapToExpressionJSON(ExpressionEO expressionEO) {
        ExpressionJSON expressionJSON = new ExpressionJSON();

        expressionJSON.setIdExpression(expressionEO.getIdExpression());
        expressionJSON.setExpression(expressionEO.getExpression());

        return expressionJSON;
    }

    public static RealizationActionJSON mapToRealizationActionJSON(RealizationActionEO realizationActionEO) {
        RealizationActionJSON realizationActionJSON = new RealizationActionJSON();

        realizationActionJSON.setIdRealization(realizationActionEO.getIdRealization());
        realizationActionJSON.setCodeAction(realizationActionEO.getCodeAction());
        realizationActionJSON.setCompulsoryRatings(realizationActionEO.getCompulsoryRatings());
        realizationActionJSON.setDateRealization(realizationActionEO.getDateRealization());
        realizationActionJSON.setDescription(realizationActionEO.getDescription());
        realizationActionJSON.setGuarantee(realizationActionEO.getGuarantee());
        realizationActionJSON.setIntendedFor(realizationActionEO.getIntendedFor());
        realizationActionJSON.setLength(realizationActionEO.getLength());
        realizationActionJSON.setMaxParticipants(realizationActionEO.getMaxParticipants());
        realizationActionJSON.setMinParticipants(realizationActionEO.getMinParticipants());
        realizationActionJSON.setNameAction(realizationActionEO.getNameAction());
        realizationActionJSON.setNote(realizationActionEO.getNote());
        realizationActionJSON.setPlace(realizationActionEO.getPlace());
        realizationActionJSON.setPrice(realizationActionEO.getPrice());
        realizationActionJSON.setPublishRating(realizationActionEO.getPublishRating());
        realizationActionJSON.setSinglePrice(realizationActionEO.getSinglePrice());
        realizationActionJSON.setTrainer(realizationActionEO.getTrainer());
        realizationActionJSON.setTransmissionReport(realizationActionEO.getTransmissionReport());
        //realizationActionJSON.setCcaAction(mapToActionJSON(realizationActionEO.getCcaAction()));
/*
        List<RegistrationJSON> registrationJSONList = new LinkedList<RegistrationJSON>();

        for(RegistrationEO registrationEO : realizationActionEO.getCcaRegistrations()) {
            registrationJSONList.add(mapToRegistrationJSON(registrationEO));
        }

        realizationActionJSON.setCcaRegistrations(registrationJSONList);
  */    realizationActionJSON.setCcaStatusAction(mapToStatusActionJSON(realizationActionEO.getCcaStatusAction()));
        realizationActionJSON.setCcaUnitMeasure(mapToUnitMeasureJSON(realizationActionEO.getCcaUnitMeasure()));
        realizationActionJSON.setCcaCurrency(mapToCurrencyJSON(realizationActionEO.getCcaCurrency()));

        return realizationActionJSON;
    }

    public static StatusActionJSON mapToStatusActionJSON(StatusActionEO statusActionEO) {
        StatusActionJSON statusActionJSON = new StatusActionJSON();

     
        statusActionJSON.setIdStatusAction(statusActionEO.getIdStatusAction());
        statusActionJSON.setStatusAction(statusActionEO.getStatusAction());

        return statusActionJSON;
    }

    public static UnitMeasureJSON mapToUnitMeasureJSON(UnitMeasureEO unitMeasureEO) {
        UnitMeasureJSON unitMeasureJSON = new UnitMeasureJSON();

       
        unitMeasureJSON.setIdUnitMeasure(unitMeasureEO.getIdUnitMeasure());
        unitMeasureJSON.setUnitMeasure(unitMeasureEO.getUnitMeasure());

        return unitMeasureJSON;
    }

    public static CurrencyJSON mapToCurrencyJSON(CurrencyEO currencyEO) {
        CurrencyJSON currencyJSON = new CurrencyJSON();
                
        currencyJSON.setAbbervivationCurrency(currencyEO.getAbbervivationCurrency());
        currencyJSON.setIdCurrency(currencyEO.getIdCurrency());
        currencyJSON.setCurrency(currencyEO.getCurrency());

        return currencyJSON;
    }
    
    
    public static LeaderJSON mapToLeaderJSON(EmployeeEO employeeEO) {
        LeaderJSON leader = new LeaderJSON();
        leader.setIdEmployee(employeeEO.getIdEmployee());
        leader.setName(employeeEO.getFirstName()+" "+employeeEO.getSurname());
        return leader;
    }

}
